==> ja-WiKicker-0.23.tbz: lib/perl5/site_perl/5.8.5/WiKicker/WikiPage/InlineBlockNode.pm <==
#
# WiKicker
#
#  InlineBlockNode.pm
#
#
# Copyright (C) 2004 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: InlineBlockNode.pm,v 1.1 2004/02/11 07:00:49 naney Exp $
#
#

package WiKicker::WikiPage::InlineBlockNode;

use strict;
use WiKicker::WikiPage::Acceptor;
use WiKicker::WikiPage::Node;

use vars qw(@ISA);

@ISA = qw(WiKicker::WikiPage::Acceptor WiKicker::WikiPage::Node);  

sub new {
  my ($class, $scheme) = @_;

  my $self = bless { child_node => [], scheme => $scheme }, $class;
}

sub scheme {
  my $self = shift;

  return $self->{scheme};
}

sub to_string {
  my $self = shift;

  if ($self->scheme eq '') {
    return "{{" . join('', map { $_->to_string } $self->nodes) . "}}";
  }
  else {
    return "{{" . $self->scheme . ':'
      . join('', map { $_->to_string } $self->nodes) . "}}";
  }
}

sub to_unarmor_string {
  my $self = shift;

  if ($self->scheme eq '') {
    return "{{" . join('', map { $_->to_unarmor_string } $self->nodes) . "}}";
  }
  else {
    return "{{" . $self->scheme . ':'
      . join('', map { $_->to_unarmor_string } $self->nodes) . "}}";
  }
}

1;

==> ja-WiKicker-0.26.tbz: lib/perl5/site_perl/5.8.9/WiKicker/WikiPage/InlineBlockNode.pm <==
#
# WiKicker
#
#  InlineBlockNode.pm
#
#
# Copyright (C) 2004 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: InlineBlockNode.pm,v 1.2 2004/08/03 12:55:52 naney Exp $
#
#

package WiKicker::WikiPage::InlineBlockNode;

use strict;
use WiKicker::WikiPage::Acceptor;
use WiKicker::WikiPage::Node;

use vars qw(@ISA);

@ISA = qw(WiKicker::WikiPage::Acceptor WiKicker::WikiPage::Node);

sub new {
  my ($class, $scheme) = @_;

  my $self = bless { child_node => [], scheme => $scheme }, $class;
}

sub scheme {
  my $self = shift;

  return $self->{scheme};
}

sub to_string {
  my $self = shift;

  if ($self->scheme eq '') {
    return '{{' . join('', map { $_->to_string } $self->nodes) . '}}';
  }
  else {
    return '{{' . $self->scheme . ':'
      . join('', map { $_->to_string } $self->nodes) . '}}';
  }
}

sub to_unarmor_string {
  my $self = shift;

  if ($self->scheme eq '') {
    return '{{' . join('', map { $_->to_unarmor_string } $self->nodes) . '}}';
  }
  else {
    return '{{' . $self->scheme . ':'
      . join('', map { $_->to_unarmor_string } $self->nodes) . '}}';
  }
}

1;
